.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.interfaces
---------------------------

.. automodule:: reahl.web.interfaces


WebUserSessionProtocol
""""""""""""""""""""""

.. autoclass:: WebUserSessionProtocol
   :members:

UserInputProtocol
"""""""""""""""""

.. autoclass:: UserInputProtocol
   :members:


PersistedExceptionProtocol
""""""""""""""""""""""""""

.. autoclass:: PersistedExceptionProtocol
   :members:


PersistedFileProtocol
"""""""""""""""""""""

.. autoclass:: PersistedFileProtocol
   :members:
